<?php
/*
Plugin Name: Auto Login
Plugin URI: http://aprz.de
Description: Automatically tries to login from the htaccess user name
Version: 1.0
Author: Abraham Przewodnik, based on sample code by Leon Bukhman and Gaspard Petit
*/
 
/* 
    Replace WordPress' Authentication-function with a function that returns the 
    corresponding WordPress-User for the logged in htaccess user as long as this 
    user is NOT in the group blocked.
     
    This makes ANY WordPress functions use the new htaccess-Authentication. The
    original authentication-methods won't be called. So it doesn't matter which
    username or password the user submits over the API or a login-form.
*/
add_filter( 'authenticate', 'htaccess_auth', 10, 3 );
function htaccess_auth( $user = "", $username = "", $password = ""){
    $username = isset($_SERVER['PHP_AUTH_USER']) 
                    ? $_SERVER['PHP_AUTH_USER'] : false;
    $user = get_user_by('login', $username);
    if ($user && !in_array("blocked", $user->roles)) return $user;
}
 
/*
    Login the current htaccess-user automatically when any page is rendered
*/
add_action('init', 'auto_login');
function auto_login() {
    $user = htaccess_auth();
    if ($user) {
        wp_set_current_user($user->ID, $user->user_login);
        if (wp_validate_auth_cookie() != $user->ID) wp_set_auth_cookie($user->ID);
        do_action('wp_login', $user->user_login);
    } elseif (is_user_logged_in()) {
        wp_clear_auth_cookie();
        do_action('wp_logout');
        wp_set_current_user(0);
    }
}
